@@ -365,6 +365,13 @@ ww_multi_scale.sf <- function(
     )
   }
 
+  if (any(names(data) %in% c(".truth", ".estimate", ".truth_count", ".estimate_count"))) {
+    rlang::abort(c(
+      "This function cannot work with data whose columns are named `.truth`, `.estimate`, `.truth_count`, or `estimate_count`.",
+      i = "Rename the relevant columns and try again."
+    ))
+  }
+
   geom_type <- unique(sf::st_geometry_type(data))
   if (!(length(geom_type) == 1 && geom_type == "POINT")) {
     rlang::abort(
@@ -447,9 +454,9 @@ ww_multi_scale.sf <- function(
       matched_data <- dplyr::summarise(
         matched_data,
         .truth = rlang::exec(.env[["aggregation_function"]], .data[[names(truth_var)]]),
-        .truth_count = sum(!is.na({{ truth }})),
+        .truth_count = sum(!is.na(.data[[names(truth_var)]])),
         .estimate = rlang::exec(.env[["aggregation_function"]], .data[[names(estimate_var)]]),
-        .estimate_count = sum(!is.na({{ estimate }})),
+        .estimate_count = sum(!is.na(.data[[names(estimate_var)]])),
         .groups = "drop"
       )
 
@@ -498,7 +505,15 @@ handle_metrics <- function(metrics) {
 handle_grids <- function(data, grids, autoexpand_grid, ...) {
   if (is.null(grids)) {
     grid_args <- rlang::list2(...)
-    grid_args <- tibble::as_tibble(do.call(cbind, grid_args))
+    grid_arg_idx <- max(vapply(grid_args, length, integer(1)))
+    grid_args <- stats::setNames(
+      lapply(
+        grid_args,
+        \(x) rep(x, length.out = grid_arg_idx)
+      ),
+      names(grid_args)
+    )
+    grid_args <- tibble::as_tibble(grid_args)
     grid_arg_idx <- seq_len(nrow(grid_args))
 
     grid_box <- sf::st_bbox(data)
@@ -511,14 +526,19 @@ handle_grids <- function(data, grids, autoexpand_grid, ...) {
       # points within the grid
       grid_box <- expand_grid(grid_box)
     }
-
-    grids <- apply(
-      grid_args,
-      1,
-      function(g_args) {
+    grids <- lapply(
+      grid_arg_idx,
+      function(idx) {
+        arg <- lapply(
+          names(grid_args),
+          function(arg) {
+            grid_args[[arg]][[idx]]
+          }
+        )
+        names(arg) <- names(grid_args)
         do.call(
           sf::st_make_grid,
-          c(g_args, x = list(grid_box))
+          c(x = list(grid_box), arg)
         )
       }
     )
